@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2016 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -84,6 +84,7 @@ class CFrontendSetup {
 		$result[] = $this->checkPhpLibxml();
 		$result[] = $this->checkPhpXmlWriter();
 		$result[] = $this->checkPhpXmlReader();
+		$result[] = $this->checkPhpLdapModule();
 		$result[] = $this->checkPhpCtype();
 		$result[] = $this->checkPhpSession();
 		$result[] = $this->checkPhpSessionAutoStart();
@@ -248,7 +249,7 @@ class CFrontendSetup {
 			'current' => empty($current) ? _('off') : new CSpan($current),
 			'required' => null,
 			'result' => $current ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _('At least one of MySQL, PostgreSQL, Oracle, SQLite3 or IBM DB2 should be supported.')
+			'error' => _('At least one of MySQL, PostgreSQL, Oracle or IBM DB2 should be supported.')
 		];
 	}
 
@@ -282,11 +283,6 @@ class CFrontendSetup {
 			$allowed_db[ZBX_DB_DB2] = 'IBM DB2';
 		}
 
-		// Semaphore related functions are checked elsewhere. The 'false' is to prevent autoloading of the SQLite3 class.
-		if (class_exists('SQLite3', false) && zbx_is_callable(['ftok', 'sem_acquire', 'sem_get', 'sem_release'])) {
-			$allowed_db[ZBX_DB_SQLITE3] = 'SQLite3';
-		}
-
 		return $allowed_db;
 	}
 
@@ -545,6 +541,23 @@ class CFrontendSetup {
 		];
 	}
 
+	/**
+	 * Checks for PHP LDAP extension.
+	 *
+	 * @return array
+	 */
+	public function checkPhpLdapModule() {
+		$current = (new CLdap())->error !== CLdap::ERR_PHP_EXTENSION;
+
+		return [
+			'name' => _('PHP LDAP'),
+			'current' => $current ? _('on') : _('off'),
+			'required' => null,
+			'result' => $current ? self::CHECK_OK : self::CHECK_WARNING,
+			'error' => _('PHP LDAP extension missing.')
+		];
+	}
+
 	/**
 	 * Checks for PHP ctype extension.
 	 *
