@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,8 +28,7 @@ if ($data['screen']['templateid']) {
 $screenBuilder = new CScreenBuilder([
 	'isFlickerfree' => false,
 	'screen' => $data['screen'],
-	'mode' => SCREEN_MODE_EDIT,
-	'updateProfile' => false
+	'mode' => SCREEN_MODE_EDIT
 ]);
 
 $widget->addItem(
