@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,18 +25,33 @@
 #include "mutexs.h"
 #include "sysinfo.h"
 
-static ZBX_PERF_STAT_DATA	ppsd;
-static ZBX_MUTEX		perfstat_access = ZBX_MUTEX_NULL;
+#define UNSUPPORTED_REFRESH_PERIOD		600
 
-#define LOCK_PERFCOUNTERS	zbx_mutex_lock(&perfstat_access)
-#define UNLOCK_PERFCOUNTERS	zbx_mutex_unlock(&perfstat_access)
+typedef struct
+{
+	zbx_perf_counter_data_t	*pPerfCounterList;
+	PDH_HQUERY		pdh_query;
+	time_t			nextcheck;	/* refresh time of not supported counters */
+}
+ZBX_PERF_STAT_DATA;
+
+static ZBX_PERF_STAT_DATA	ppsd;
+static zbx_mutex_t		perfstat_access = ZBX_MUTEX_NULL;
+
+#define LOCK_PERFCOUNTERS	zbx_mutex_lock(perfstat_access)
+#define UNLOCK_PERFCOUNTERS	zbx_mutex_unlock(perfstat_access)
+
+static int	perf_collector_started(void)
+{
+	return (NULL != ppsd.pdh_query ? SUCCEED : FAIL);
+}
 
 /******************************************************************************
  *                                                                            *
  * Comments: counter failed or disappeared, dismiss all previous values       *
  *                                                                            *
  ******************************************************************************/
-static void	deactivate_perf_counter(PERF_COUNTER_DATA *counter)
+static void	deactivate_perf_counter(zbx_perf_counter_data_t *counter)
 {
 	zabbix_log(LOG_LEVEL_DEBUG, "deactivate_perf_counter() counterpath:'%s'", counter->counterpath);
 
@@ -53,10 +68,10 @@ static void	deactivate_perf_counter(PERF_COUNTER_DATA *counter)
  *           added, a pointer to that counter is returned, NULL otherwise     *
  *                                                                            *
  ******************************************************************************/
-PERF_COUNTER_DATA	*add_perf_counter(const char *name, const char *counterpath, int interval, char **error)
+zbx_perf_counter_data_t	*add_perf_counter(const char *name, const char *counterpath, int interval, char **error)
 {
 	const char		*__function_name = "add_perf_counter";
-	PERF_COUNTER_DATA	*cptr = NULL;
+	zbx_perf_counter_data_t	*cptr = NULL;
 	PDH_STATUS		pdh_status;
 	int			added = FAIL;
 
@@ -75,10 +90,10 @@ PERF_COUNTER_DATA	*add_perf_counter(const char *name, const char *counterpath, i
 		/* add new parameters */
 		if (NULL == cptr)
 		{
-			cptr = (PERF_COUNTER_DATA *)zbx_malloc(cptr, sizeof(PERF_COUNTER_DATA));
+			cptr = (zbx_perf_counter_data_t *)zbx_malloc(cptr, sizeof(zbx_perf_counter_data_t));
 
 			/* initialize the counter */
-			memset(cptr, 0, sizeof(PERF_COUNTER_DATA));
+			memset(cptr, 0, sizeof(zbx_perf_counter_data_t));
 			if (NULL != name)
 				cptr->name = zbx_strdup(NULL, name);
 			cptr->counterpath = zbx_strdup(NULL, counterpath);
@@ -141,7 +156,7 @@ out:
  *             interval  - [IN] the new data collection interval in seconds   *
  *                                                                            *
  ******************************************************************************/
-static void	extend_perf_counter_interval(PERF_COUNTER_DATA *counter, int interval)
+static void	extend_perf_counter_interval(zbx_perf_counter_data_t *counter, int interval)
 {
 	if (interval <= counter->interval)
 		return;
@@ -170,9 +185,9 @@ static void	extend_perf_counter_interval(PERF_COUNTER_DATA *counter, int interva
  *           the memory is freed - do not use it again                        *
  *                                                                            *
  ******************************************************************************/
-void	remove_perf_counter(PERF_COUNTER_DATA *counter)
+void	remove_perf_counter(zbx_perf_counter_data_t *counter)
 {
-	PERF_COUNTER_DATA	*cptr;
+	zbx_perf_counter_data_t	*cptr;
 
 	LOCK_PERFCOUNTERS;
 
@@ -205,9 +220,9 @@ out:
 
 }
 
-static void	free_perf_counter_list()
+static void	free_perf_counter_list(void)
 {
-	PERF_COUNTER_DATA	*cptr;
+	zbx_perf_counter_data_t	*cptr;
 
 	LOCK_PERFCOUNTERS;
 
@@ -231,7 +246,7 @@ static void	free_perf_counter_list()
  *           interval must be less than or equal to counter->interval         *
  *                                                                            *
  ******************************************************************************/
-double	compute_average_value(PERF_COUNTER_DATA *counter, int interval)
+static double	compute_average_value(zbx_perf_counter_data_t *counter, int interval)
 {
 	double	sum = 0;
 	int	i, j, count;
@@ -253,24 +268,32 @@ double	compute_average_value(PERF_COUNTER_DATA *counter, int interval)
 	return sum / (double)count;
 }
 
-int	init_perf_collector(int multithreaded)
+int	init_perf_collector(zbx_threadedness_t threadedness, char **error)
 {
 	const char	*__function_name = "init_perf_collector";
 	int		ret = FAIL;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __function_name);
 
-	if (0 != multithreaded)
+	switch (threadedness)
 	{
-		if (FAIL == zbx_mutex_create_force(&perfstat_access, ZBX_MUTEX_PERFSTAT))
-		{
-			zbx_error("cannot create mutex for performance counters");
-			exit(EXIT_FAILURE);
-		}
+		case ZBX_SINGLE_THREADED:
+			break;
+		case ZBX_MULTI_THREADED:
+			if (SUCCEED != zbx_mutex_create(&perfstat_access, ZBX_MUTEX_PERFSTAT, error))
+				goto out;
+			break;
+		default:
+			THIS_SHOULD_NEVER_HAPPEN;
+			*error = zbx_strdup(*error, "internal error");
+			goto out;
 	}
 
 	if (ERROR_SUCCESS != zbx_PdhOpenQuery(__function_name, &ppsd.pdh_query))
+	{
+		*error = zbx_strdup(*error, "cannot open performance data query");
 		goto out;
+	}
 
 	ppsd.nextcheck = time(NULL) + UNSUPPORTED_REFRESH_PERIOD;
 
@@ -281,14 +304,9 @@ out:
 	return ret;
 }
 
-int	perf_collector_started()
+void	free_perf_collector(void)
 {
-	return (NULL != ppsd.pdh_query ? SUCCEED : FAIL);
-}
-
-void	free_perf_collector()
-{
-	PERF_COUNTER_DATA	*cptr;
+	zbx_perf_counter_data_t	*cptr;
 
 	if (SUCCEED != perf_collector_started())
 		return;
@@ -310,10 +328,10 @@ void	free_perf_collector()
 	zbx_mutex_destroy(&perfstat_access);
 }
 
-void	collect_perfstat()
+void	collect_perfstat(void)
 {
 	const char		*__function_name = "collect_perfstat";
-	PERF_COUNTER_DATA	*cptr;
+	zbx_perf_counter_data_t	*cptr;
 	PDH_STATUS		pdh_status;
 	time_t			now;
 	PDH_FMT_COUNTERVALUE	value;
@@ -462,7 +480,7 @@ int	get_perf_counter_value_by_name(const char *name, double *value, char **error
 {
 	const char		*__function_name = "get_perf_counter_value_by_name";
 	int			ret = FAIL;
-	PERF_COUNTER_DATA	*perfs = NULL;
+	zbx_perf_counter_data_t	*perfs = NULL;
 	char			*counterpath = NULL;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() name:%s", __function_name, name);
@@ -537,7 +555,7 @@ int	get_perf_counter_value_by_path(const char *counterpath, int interval, double
 {
 	const char		*__function_name = "get_perf_counter_value_by_path";
 	int			ret = FAIL;
-	PERF_COUNTER_DATA	*perfs = NULL;
+	zbx_perf_counter_data_t	*perfs = NULL;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() path:%s interval:%d", __function_name, counterpath, interval);
 
@@ -599,7 +617,7 @@ out:
  *           FAIL    - otherwise                                              *
  *                                                                            *
  ******************************************************************************/
-int	get_perf_counter_value(PERF_COUNTER_DATA *counter, int interval, double *value, char **error)
+int	get_perf_counter_value(zbx_perf_counter_data_t *counter, int interval, double *value, char **error)
 {
 	const char	*__function_name = "get_perf_counter_value";
 	int		ret = FAIL;
@@ -629,8 +647,3 @@ out:
 
 	return ret;
 }
-
-
-
-
-
